import React, { useEffect, useRef, useState } from 'react';
import { Modal, Button } from 'antd';
import loader from '@/components/AMap/loader';
import getMarker from './marker';
import getRuralMarker from './RuralMarker';
import getCarsMarker from './CarsMarker';

import geoPolygon from './geoPolygon';
import Styles from './style.less';

const plugins = [];



export default (props) => {


  const container = useRef();
  const amapRef = useRef();
  const [map, setMap] = useState();

  const [isModalVisible, setIsModalVisible] = useState(false)

  window.openVideo = function () {
    console.log(' window.foo 全局方法');
    setIsModalVisible(true)

  }

  useEffect(() => {
    loader(plugins).then((AMap) => {
      amapRef.current = AMap;
      const mapInst = new AMap.Map(container.current, {
        mapStyle: 'amap://styles/669a7d8709a9bab0945747a1a1db3327',
        // mapStyle: 'amap://styles/blue',
        zoom: 10,
        resizeEnable: true,
        center: [112.092716, 32.681642],
      });

      // 遮罩层;
      geoPolygon(AMap, mapInst);

      //
      setMap(mapInst);
    });
  }, []);

  useEffect(() => {
    if (!map) return;

    // 先搞一个 marker demo
    getMarker(amapRef.current, map, {
      position: [112.092716, 32.681642],
      extData: { value: '68辆' },
    });


    // 合作社图标定位
    getRuralMarker(amapRef.current, map, {
      position: [111.909659, 32.651123],
      extData: {
        ruralName: 'ABC合作社',
        ruralAddress: '南阳市邓州市林扒镇',
        ruralNumber: '9辆',
        ruralPhone: '13613949434',
      }
    })

    // 农机监控
    getCarsMarker(amapRef.current, map, {
      position: [112.115574, 32.65235],
      extData: {
        carsName: '播种机0001',
        carsRural: 'ABC合作社',
      }
    })
  }, [map]);

  return (
    <div className={Styles['geo-map-container']}>
      {/* 占位图片 */}
      <div className={Styles['geo-map-header']}>
        <div />
        <div />
        <div />
      </div>

      <div className={Styles['geo-map-body']}>
        <div ref={container} />
      </div>

      {/* 占位图片 */}
      <div className={Styles['geo-map-footer']}>
        <div />
        <div />
        <div />
      </div>
      <Modal title="农机监控" footer={null} visible={isModalVisible} onCancel={() => setIsModalVisible(false)}>
        <video width="320" height="240" controls src='https://www.runoob.com/try/demo_source/movie.mp4'>
          <source src="movie.mp4" type="video/mp4" />
          <source src="movie.ogg" type="video/ogg" />
          您的浏览器不支持 video 。
        </video>

      </Modal>
    </div>
  );
};
